==> pyloadl-0.2.0.tar.bz2: pyloadl-0.2.0/examples/llbg/bg_bp_query.py <==
from pyloadl import *
from time import gmtime, strftime
from sys import exit

"""

   Displays information on the LoadLeveler queue 
   similar to the llq command

"""

partitionStateString = [ "FREE", "CFG", "READY", "BUSY",
                         "DEALC", "ERROR", "NAV" ]

bpStateString= [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

# Query Blue Gene information

query = ll_query(BLUE_GENE);
if not PyCObjValid(query):
   print "ll_query(): returns NULL\n" 
   exit(-1)

retval = ll_set_request(query, QUERY_BG_BASE_PARTITION, ["All"], ALL_DATA)
if retval != 0:
   print "ll_set_request(): error %d\n" % retval
   exit(-1)

# Get the machine objects from the LoadL_negotiator (central manager) daemon

machine, obj_count, err_code = ll_get_objs(query, LL_CM, "")
if err_code != 0:
    print "Query MACHINES: ll_get_objs() returns NULL. Error code =  %d" % err_code
    exit(-1)

BP_size = []
BP_size = ll_get_data(machine, LL_BgMachineBPSize)
if len(BP_size) > 0:
   print BP_size
   print "Machine BP_size = %s %s %s\n" % (BP_size[0], BP_size[1], BP_size[2])

bp = ll_get_data(machine, LL_BgMachineGetFirstBP)
while PyCObjValid(bp):
    BP_id = ll_get_data(bp, LL_BgBPId)
    print "Base Partition ID - %s" % BP_id
    state = ll_get_data(bp, LL_BgBPState)
    status = partitionStateString[state]
    print "\tState - %s" % status
    size = ll_get_data(bp, LL_BgBPLocation)
    print "\tSize - %s" % size
    Busy = ll_get_data(bp, LL_BgBPSubDividedBusy)
    print "\tDiv Busy - %s" % Busy
    partition = ll_get_data(bp, LL_BgBPCurrentPartition)
    print "\tCurrent Partition - %s" % partition
    partition_state = ll_get_data(bp, LL_BgBPCurrentPartitionState)

    if len(partition) == 0:
       partid = "NONE"
       partstate = "NONE"
    else:
       partid = partition
       partstate = partitionStateString[partition_state]

    print "\tCurrent Partition - %s" % partid
    print "\tCurrent Partition State - %s" % partstate
    node_card_count = ll_get_data(bp, LL_BgBPNodeCardCount)
    print "\tNode Card Count - %s" % node_card_count

    node_card = ll_get_data(bp, LL_BgBPGetFirstNodeCard)
    while PyCObjValid(node_card): 
        node_card_id = ll_get_data(node_card, LL_BgNodeCardId)
        node_card_state = ll_get_data(node_card, LL_BgNodeCardState)
        node_card_qrt = ll_get_data(node_card, LL_BgNodeCardQuarter)
        node_card_part = ll_get_data(node_card, LL_BgNodeCardCurrentPartition)
        node_card_cps = ll_get_data(node_card, LL_BgNodeCardCurrentPartitionState)
        print "\t\tNode Card Id  : %s"  % (node_card_id)
        print "\t\t\tCard State     : %s" % (node_card_state)
        print "\t\t\tCard Quarter   : %s" % (node_card_qrt)
        print "\t\t\tCard Partition : %s" % (node_card_part)
        status = partitionStateString[node_card_cps]
        print "\t\t\tCard PState    : %s" % (status )
        node_card = ll_get_data(bp, LL_BgBPGetNextNodeCard)

    bp = ll_get_data(machine, LL_BgMachineGetNextBP)

==> pyloadl-0.4.3.tar.bz2: pyloadl-0.4.3/examples/llbg/bg_bp_query.py <==
from pyloadl import *
from time import gmtime, strftime
from sys import exit

"""

   Blue Gene Base Partition Query

"""

partitionStateString = [ "FREE", "CFG", "READY", "BUSY",
                         "DEALC", "ERROR", "NAV" ]

bpStateString= [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

# Query Blue Gene information

query = ll_query(BLUE_GENE)
if not PyCObjValid(query):
   print "ll_query(): returns NULL\n" 
   exit(-1)

retval = ll_set_request(query, QUERY_BG_BASE_PARTITION, ["All"], ALL_DATA)
if retval != 0:
   print "ll_set_request(): error %d\n" % retval
   exit(-1)

# Get the machine objects from the LoadL_negotiator (central manager) daemon

machine, obj_count, err_code = ll_get_objs(query, LL_CM, "")
if err_code != 0:
    print "Query MACHINES: ll_get_objs() returns NULL. Error code =  %d" % err_code
    exit(-1)

BP_size = []
BP_size = ll_get_data(machine, LL_BgMachineBPSize)
if len(BP_size) > 0:
   print BP_size
   print "Machine BP_size = %s %s %s\n" % (BP_size[0], BP_size[1], BP_size[2])

bp = ll_get_data(machine, LL_BgMachineGetFirstBP)
while PyCObjValid(bp):
    BP_id = ll_get_data(bp, LL_BgBPId)
    print "Base Partition ID - %s" % BP_id
    state = ll_get_data(bp, LL_BgBPState)
    status = partitionStateString[state]
    print "\tState - %s" % status
    size = ll_get_data(bp, LL_BgBPLocation)
    print "\tSize - %s" % size
    Busy = ll_get_data(bp, LL_BgBPSubDividedBusy)
    print "\tDiv Busy - %s" % Busy
    partition = ll_get_data(bp, LL_BgBPCurrentPartition)
    print "\tCurrent Partition - %s" % partition
    partition_state = ll_get_data(bp, LL_BgBPCurrentPartitionState)

    if len(partition) == 0:
       partid = "NONE"
       partstate = "NONE"
    else:
       partid = partition
       partstate = partitionStateString[partition_state]

    print "\tCurrent Partition - %s" % partid
    print "\tCurrent Partition State - %s" % partstate
    node_card_count = ll_get_data(bp, LL_BgBPNodeCardCount)
    print "\tNode Card Count - %s" % node_card_count

    node_card = ll_get_data(bp, LL_BgBPGetFirstNodeCard)
    while PyCObjValid(node_card): 
        node_card_id = ll_get_data(node_card, LL_BgNodeCardId)
        node_card_state = ll_get_data(node_card, LL_BgNodeCardState)
        node_card_qrt = ll_get_data(node_card, LL_BgNodeCardQuarter)
        node_card_part = ll_get_data(node_card, LL_BgNodeCardCurrentPartition)
        node_card_cps = ll_get_data(node_card, LL_BgNodeCardCurrentPartitionState)
        print "\t\tNode Card Id  : %s"  % (node_card_id)
        print "\t\t\tCard State     : %s" % (node_card_state)
        print "\t\t\tCard Quarter   : %s" % (node_card_qrt)
        print "\t\t\tCard Partition : %s" % (node_card_part)
        status = partitionStateString[node_card_cps]
        print "\t\t\tCard PState    : %s" % (status )
        node_card = ll_get_data(bp, LL_BgBPGetNextNodeCard)

    bp = ll_get_data(machine, LL_BgMachineGetNextBP)
